#! /bin/bash
#
# This script executes a task under the control of the 0mq worker.
# It is past an absolute file name as the only argument. The script
# should be able to function stand-alone for testing, or under
# worker control.
#
# What follows is an example of what might be done, but is really
# limited only to the script used. Any other scripting language
# could be used, even a binary program.

# Set a variable as the absolute path to an executable.

BLASTN=/usr/local/packages/bioinformatics/ncbiblast/2.2.28/gcc-4.4.6/bin/blastn

# Let's run multithreaded, with, say, 4 threads per task. Needs to
# be consistent with settings in the PBS file.

export OMP_NUM_THREADS=4

# Capture the input file from the argument list, and split it into
# the directory path part, and the basename part (name less extension).

FILE=$1
DIR=`dirname ${FILE}`
BASE=`basename ${FILE}`

# Build the rather complex command line. 

CMD="${NUMACTL_PREFIX}"
CMD="${CMD} ${BLASTN} -task blastn -outfmt 7 -max_target_seqs 1"
CMD="${CMD} -num_threads ${OMP_NUM_THREADS}"
CMD="${CMD} -db /project/jcthrash/db/img_v400_custom/img_v400_custom_GENOME"
CMD="${CMD} -query ${FILE}"
CMD="${CMD} -out ${DIR}/IMG_genome_blast.${BASE}"

# Execute the desired processing steps. Again, more than one is
# possible. This example runs BLASTN against a particular database.
# For testing purposes, use "if false". For real runs, use "if true":

if false ; then
   eval "${CMD}"
else
   echo "${CMD}"
   # This just slows things way down for testing.
   sleep 1
fi
