#! /bin/bash
#
# This script does nothing except provide a template for a
# WQ command script. Other than handling a single command line
# argument, anything is possible.

# For instance, if the argument is an absolute path to an input file,
# then one could extract the directory path part, and the basename part
# (name less extension) to use in execution setup:

FILE=$1
DIR=`dirname ${FILE}`
BASE=`basename ${FILE}`

# Other shell magic could come here, like setting up for a small
# MPI run. For OpenMPI, we'd need to build a comma separated list of
# host names (no spaces!), with one name per process desired. 

PROCS=2
HOSTNAME=`uname -n`
HOSTLIST=""
for i in `seq 1 $PROCS`; do
   HOSTLIST="${HOSTNAME},${HOSTLIST}"
done 
HOSTLIST=${HOSTLIST%,*}

# Here we create the command line as a string to either display or
# execute later. This is only one of a miriad ways to handle it.

CMD="mpirun -host ${HOSTLIST} -np ${PROCS} mb < ${FILE} > ${BASE}.out"

# If we want the output of the run to be in the same directory as the
# input file, cd to the directory determined above.

cd $DIR

# For testing purposes, use "if false", and each call will generate
# the command line string, a message about the nodes assigned, and
# then sleep for some time. For actual production, use "if true", and 
# the command will be executed instead. Of course, any other
# processing could be done as well. This is basically just another
# shell script, so adjust to your hearts content. 

if false ; then
   echo "${CMD}"
   echo "Faking it on HOSTLIST=${HOSTLIST}"
   sleep 2
else
   eval "${CMD}"
fi
